==> cscec5b-xell-impl-3.0.1-20230303.030542-59-sources.jar: com/ejianc/business/wzxt/bean/CauseDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 节超原因子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_cause_detail")
public class CauseDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="cause_id")
    private Long causeId; // 主表id
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="construction_detail")
    private String constructionDetail; // 部位名称
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="design_nums")
    private BigDecimal designNums; // 设计用量
    @TableField(value="plan_nums")
    private BigDecimal planNums; // 计划用量
    @TableField(value="reality_nums")
    private BigDecimal realityNums; // 实际用量
    @TableField(value="quota_nums")
    private BigDecimal quotaNums; // 定额用量
    @TableField(value="duty_save_rate")
    private BigDecimal dutySaveRate; // 目标节约率
    @TableField(value="duty_nums")
    private BigDecimal dutyNums; // 目标用量
    @TableField(value="exceed_rate")
    private BigDecimal exceedRate; // 节超率
    @TableField(value="duty_person_detail_id")
    private Long dutyPersonDetailId; // 责任人ID
    @TableField(value="duty_person_detail_name")
    private String dutyPersonDetailName; // 责任人
    @TableField(value="duty_section_detail")
    private String dutySectionDetail; // 责任工区
    @TableField(value="exceed_cause_detail")
    private String exceedCauseDetail; // 节超原因分析
    @TableField(value="improvement_measure_detail")
    private String improvementMeasureDetail; // 改进措施
    
    
    

    public Long getCauseId() {
        return causeId;
    }

    public void setCauseId(Long causeId) {
        this.causeId = causeId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getConstructionDetail() {
        return constructionDetail;
    }

    public void setConstructionDetail(String constructionDetail) {
        this.constructionDetail = constructionDetail;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getDesignNums() {
        return designNums;
    }

    public void setDesignNums(BigDecimal designNums) {
        this.designNums = designNums;
    }
    public BigDecimal getPlanNums() {
        return planNums;
    }

    public void setPlanNums(BigDecimal planNums) {
        this.planNums = planNums;
    }
    public BigDecimal getRealityNums() {
        return realityNums;
    }

    public void setRealityNums(BigDecimal realityNums) {
        this.realityNums = realityNums;
    }
    public BigDecimal getQuotaNums() {
        return quotaNums;
    }

    public void setQuotaNums(BigDecimal quotaNums) {
        this.quotaNums = quotaNums;
    }
    public BigDecimal getDutySaveRate() {
        return dutySaveRate;
    }

    public void setDutySaveRate(BigDecimal dutySaveRate) {
        this.dutySaveRate = dutySaveRate;
    }
    public BigDecimal getDutyNums() {
        return dutyNums;
    }

    public void setDutyNums(BigDecimal dutyNums) {
        this.dutyNums = dutyNums;
    }
    public BigDecimal getExceedRate() {
        return exceedRate;
    }

    public void setExceedRate(BigDecimal exceedRate) {
        this.exceedRate = exceedRate;
    }
    public Long getDutyPersonDetailId() {
        return dutyPersonDetailId;
    }

    public void setDutyPersonDetailId(Long dutyPersonDetailId) {
        this.dutyPersonDetailId = dutyPersonDetailId;
    }
    public String getDutyPersonDetailName() {
        return dutyPersonDetailName;
    }

    public void setDutyPersonDetailName(String dutyPersonDetailName) {
        this.dutyPersonDetailName = dutyPersonDetailName;
    }
    public String getDutySectionDetail() {
        return dutySectionDetail;
    }

    public void setDutySectionDetail(String dutySectionDetail) {
        this.dutySectionDetail = dutySectionDetail;
    }
    public String getExceedCauseDetail() {
        return exceedCauseDetail;
    }

    public void setExceedCauseDetail(String exceedCauseDetail) {
        this.exceedCauseDetail = exceedCauseDetail;
    }
    public String getImprovementMeasureDetail() {
        return improvementMeasureDetail;
    }

    public void setImprovementMeasureDetail(String improvementMeasureDetail) {
        this.improvementMeasureDetail = improvementMeasureDetail;
    }
    
}

==> cscec5b-xell-impl-3.0.1-20250407.033944-86-sources.jar: com/ejianc/business/wzxt/bean/CauseDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 节超原因子表
 *
 * @author generator
 *
 */
 @TableName("ejc_wzxt_cause_detail")
public class CauseDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="cause_id")
    private Long causeId; // 主表id
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="construction_detail")
    private String constructionDetail; // 部位名称
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="design_nums")
    private BigDecimal designNums; // 设计用量
    @TableField(value="plan_nums")
    private BigDecimal planNums; // 计划用量
    @TableField(value="reality_nums")
    private BigDecimal realityNums; // 实际用量
    @TableField(value="quota_nums")
    private BigDecimal quotaNums; // 定额用量
    @TableField(value="duty_save_rate")
    private BigDecimal dutySaveRate; // 目标节约率
    @TableField(value="duty_nums")
    private BigDecimal dutyNums; // 目标用量
    @TableField(value="exceed_rate")
    private BigDecimal exceedRate; // 节超率
    @TableField(value="duty_person_detail_id")
    private Long dutyPersonDetailId; // 责任人ID
    @TableField(value="duty_person_detail_name")
    private String dutyPersonDetailName; // 责任人
    @TableField(value="duty_section_detail")
    private String dutySectionDetail; // 责任工区
    @TableField(value="exceed_cause_detail")
    private String exceedCauseDetail; // 节超原因分析
    @TableField(value="improvement_measure_detail")
    private String improvementMeasureDetail; // 改进措施
    @TableField(exist = false)
    private Long wbsId; // wbsId



    public Long getCauseId() {
        return causeId;
    }

    public void setCauseId(Long causeId) {
        this.causeId = causeId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getConstructionDetail() {
        return constructionDetail;
    }

    public void setConstructionDetail(String constructionDetail) {
        this.constructionDetail = constructionDetail;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getDesignNums() {
        return designNums;
    }

    public void setDesignNums(BigDecimal designNums) {
        this.designNums = designNums;
    }
    public BigDecimal getPlanNums() {
        return planNums;
    }

    public void setPlanNums(BigDecimal planNums) {
        this.planNums = planNums;
    }
    public BigDecimal getRealityNums() {
        return realityNums;
    }

    public void setRealityNums(BigDecimal realityNums) {
        this.realityNums = realityNums;
    }
    public BigDecimal getQuotaNums() {
        return quotaNums;
    }

    public void setQuotaNums(BigDecimal quotaNums) {
        this.quotaNums = quotaNums;
    }
    public BigDecimal getDutySaveRate() {
        return dutySaveRate;
    }

    public void setDutySaveRate(BigDecimal dutySaveRate) {
        this.dutySaveRate = dutySaveRate;
    }
    public BigDecimal getDutyNums() {
        return dutyNums;
    }

    public void setDutyNums(BigDecimal dutyNums) {
        this.dutyNums = dutyNums;
    }
    public BigDecimal getExceedRate() {
        return exceedRate;
    }

    public void setExceedRate(BigDecimal exceedRate) {
        this.exceedRate = exceedRate;
    }
    public Long getDutyPersonDetailId() {
        return dutyPersonDetailId;
    }

    public void setDutyPersonDetailId(Long dutyPersonDetailId) {
        this.dutyPersonDetailId = dutyPersonDetailId;
    }
    public String getDutyPersonDetailName() {
        return dutyPersonDetailName;
    }

    public void setDutyPersonDetailName(String dutyPersonDetailName) {
        this.dutyPersonDetailName = dutyPersonDetailName;
    }

    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }

    public String getDutySectionDetail() {
        return dutySectionDetail;
    }

    public void setDutySectionDetail(String dutySectionDetail) {
        this.dutySectionDetail = dutySectionDetail;
    }
    public String getExceedCauseDetail() {
        return exceedCauseDetail;
    }

    public void setExceedCauseDetail(String exceedCauseDetail) {
        this.exceedCauseDetail = exceedCauseDetail;
    }
    public String getImprovementMeasureDetail() {
        return improvementMeasureDetail;
    }

    public void setImprovementMeasureDetail(String improvementMeasureDetail) {
        this.improvementMeasureDetail = improvementMeasureDetail;
    }

}
